@@ -2,7 +2,7 @@
  * windows_common.h: Windows Audio common code
  *****************************************************************************
  * Copyright (C) 2001-2009 VideoLAN
- * $Id: b1acd06caf9087de53da7c02de67190ec3cc8e5f $
+ * $Id: 7dc74c20d30a675ae10cd9e472de661cb00c013b $
  *
  * Authors: Gildas Bazin <gbazin@videolan.org>
  *          Jean-Baptiste Kempf <jb@videolan.org>
@@ -98,34 +98,40 @@ typedef struct {
 #endif
 
 #ifndef DSSPEAKER_DSSPEAKER_DIRECTOUT
-#   define DSSPEAKER_DSSPEAKER_DIRECTOUT         0x00000000
+#   define DSSPEAKER_DSSPEAKER_DIRECTOUT  0x00000000
 #endif
 #ifndef DSSPEAKER_HEADPHONE
-#   define DSSPEAKER_HEADPHONE         0x00000001
+#   define DSSPEAKER_HEADPHONE            0x00000001
 #endif
 #ifndef DSSPEAKER_MONO
-#   define DSSPEAKER_MONO              0x00000002
+#   define DSSPEAKER_MONO                 0x00000002
 #endif
 #ifndef DSSPEAKER_QUAD
-#   define DSSPEAKER_QUAD              0x00000003
+#   define DSSPEAKER_QUAD                 0x00000003
 #endif
 #ifndef DSSPEAKER_STEREO
-#   define DSSPEAKER_STEREO            0x00000004
+#   define DSSPEAKER_STEREO               0x00000004
 #endif
 #ifndef DSSPEAKER_SURROUND
-#   define DSSPEAKER_SURROUND          0x00000005
+#   define DSSPEAKER_SURROUND             0x00000005
 #endif
 #ifndef DSSPEAKER_5POINT1
-#   define DSSPEAKER_5POINT1           0x00000006
+#   define DSSPEAKER_5POINT1              0x00000006
+#endif
+#ifndef DSSPEAKER_5POINT1_BACK
+#   define DSSPEAKER_5POINT1_BACK         DSSPEAKER_5POINT1
 #endif
 #ifndef DSSPEAKER_7POINT1
-#   define DSSPEAKER_7POINT1           0x00000007
+#   define DSSPEAKER_7POINT1              0x00000007
 #endif
 #ifndef DSSPEAKER_7POINT1_SURROUND
-#   define DSSPEAKER_7POINT1_SURROUND           0x00000008
+#   define DSSPEAKER_7POINT1_SURROUND     0x00000008
+#endif
+#ifndef DSSPEAKER_5POINT1_SURROUND
+#   define DSSPEAKER_5POINT1_SURROUND     0x00000009
 #endif
 #ifndef DSSPEAKER_7POINT1_WIDE
-#   define DSSPEAKER_7POINT1_WIDE           DSSPEAKER_7POINT1
+#   define DSSPEAKER_7POINT1_WIDE         DSSPEAKER_7POINT1
 #endif
 
 static const uint32_t pi_channels_src[] =
