@@ -2,7 +2,7 @@
  * ToolbarEdit.hpp : ToolbarEdit dialogs
  ****************************************************************************
  * Copyright (C) 2008-2011 the VideoLAN team
- * $Id: 8aafeb67bae55200fef885a25758ecb422959346 $
+ * $Id: 0b8dc44de887d43e53c78d9daab13fd666225f0b $
  *
  * Authors: Jean-Baptiste Kempf <jb (at) videolan.org>
  *
@@ -31,7 +31,7 @@
 #include <QCheckBox>
 
 #define PROFILE_NAME_1 "VLC 1.1.x Style"
-#define VALUE_1 "0|64;39;64;38;65;|0-2;64;3;1;4;64;7;9;64;10;20;19;64-4;37;65;35-4;|12;11;13;14;|5-1;33;6-1;|0-2;64;3;1;4;64;37;64;38;64;8;65;25;35-4;34;"
+#define VALUE_1 "0|64;39;64;38;65;|0-2;64;3;1;4;64;7;10;9;64-4;20;19;64-4;37;65;35-4;|12;11;13;14;|5-1;33;6-1;|0-2;64;3;1;4;64;37;64;38;64;8;65;25;35-4;34;"
 #define PROFILE_NAME_2 "VLC 0.8.x Style"
 #define VALUE_2 "1|64;39-1;64;38;|2-1;32-4;0-5;1-5;32-5;3-5;5-5;6-5;4-5;32-5;10-1;64-1;35-1;65;|12-1;11-1;13-1;14-1;|33;37-4;|0-5;1-5;32-1;1-5;5-1;6-1;4-5;32-1;12-5;11-1;65;34-4;35-1;"
 #define PROFILE_NAME_3 "Minimalist Style"
@@ -40,6 +40,8 @@
 #define VALUE_4 "0|64;38;65;|0-4;64;3;1;4;64;7;10;9;64-4;39;64-4;37;65;36-4;|12;11;14;13;|5-1;33;6-1;|0-2;64;3;1;4;64;37;64;38;64;8;65;25;35-4;34;"
 #define PROFILE_NAME_5 "Simplest Style"
 #define VALUE_5 "0||36-4;65-4;0-7;4-5;1-5;65-4;7-5;|12-4;11;13;||36-4;65-4;0-5;4-5;1-5;65;8-5;"
+#define PROFILE_NAME_6 "VLC 2.x.x Style"
+#define VALUE_6 "0|64;39;64;38;65;|0-2;64;3;1;4;64;7;9;64;10;20;19;64-4;37;65;35-4;|12;11;13;14;|43;33-4;44;|0-2;64;3;1;4;64;37;64;38;64;8;65;25;35-4;34;"
 
 class ToolbarEditDialog;
 class DroppingController;
